==> haskell-rfc5051-0.1.0.3-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-rfc5051.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: rfc5051
version: 0.1.0.3
id: rfc5051-0.1.0.3-KPG7rcO6WSd6O4FKgnm4ux
key: rfc5051-0.1.0.3-KPG7rcO6WSd6O4FKgnm4ux
license: BSD3
copyright: (C) 2013 John MacFarlane
maintainer: jgm@berkeley.edu
synopsis: Simple unicode collation as per RFC5051.
description:
    This library implements @i;unicode-casemap@,
    the simple, non locale-sensitive unicode collation
    algorithm described in RFC 5051 (<http://www.rfc-editor.org/rfc/rfc5051.txt>).
    Proper unicode collation can be done using text-icu, but that is a big
    dependency that depends on a large C library, and rfc5051 might be better
    for some purposes.
    .
    Here is a list of strings sorted by the Prelude'\''s @sort@ function:
    .
    @Abe Oeb abe ab&#233; oeb &#193;be &#196;be &#212;eb &#225;be &#228;be &#244;eb@
    .
    Here is the same list sorted by @sortBy compareUnicode@:
    .
    @Abe abe ab&#233; &#193;be &#225;be &#196;be &#228;be Oeb oeb &#212;eb &#244;eb@
category: Text
author: John MacFarlane
exposed: True
indefinite: False
exposed-modules:
    Data.RFC5051
hidden-modules: Data.RFC5051.UnicodeData Data.RFC5051.Types
abi: 6b13721840e53dffef0f5d3c88176913
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/rfc5051-0.1.0.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/rfc5051-0.1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/rfc5051-0.1.0.3
hs-libraries: HSrfc5051-0.1.0.3-KPG7rcO6WSd6O4FKgnm4ux
depends:
    base-4.10.0.0 containers-0.5.10.2 bytestring-0.10.8.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
haddock-interfaces: /usr/share/doc/haskell-rfc5051/html/rfc5051.haddock
haddock-html: /usr/share/doc/haskell-rfc5051/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rfc5051-0.1.0.3-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-rfc5051.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: rfc5051
version: 0.1.0.3
id: rfc5051-0.1.0.3-8PtQlFAd1sC8Q5UNxFfTWs
key: rfc5051-0.1.0.3-8PtQlFAd1sC8Q5UNxFfTWs
license: BSD3
copyright: (C) 2013 John MacFarlane
maintainer: jgm@berkeley.edu
synopsis: Simple unicode collation as per RFC5051.
description:
    This library implements @i;unicode-casemap@,
    the simple, non locale-sensitive unicode collation
    algorithm described in RFC 5051 (<http://www.rfc-editor.org/rfc/rfc5051.txt>).
    Proper unicode collation can be done using text-icu, but that is a big
    dependency that depends on a large C library, and rfc5051 might be better
    for some purposes.
    .
    Here is a list of strings sorted by the Prelude'\''s @sort@ function:
    .
    @Abe Oeb abe ab&#233; oeb &#193;be &#196;be &#212;eb &#225;be &#228;be &#244;eb@
    .
    Here is the same list sorted by @sortBy compareUnicode@:
    .
    @Abe abe ab&#233; &#193;be &#225;be &#196;be &#228;be Oeb oeb &#212;eb &#244;eb@
category: Text
author: John MacFarlane
exposed: True
indefinite: False
exposed-modules:
    Data.RFC5051
hidden-modules: Data.RFC5051.UnicodeData Data.RFC5051.Types
abi: 3b5ad9b9e8f9479db9a5fc2ae023f986
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/rfc5051-0.1.0.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/rfc5051-0.1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/rfc5051-0.1.0.3
hs-libraries: HSrfc5051-0.1.0.3-8PtQlFAd1sC8Q5UNxFfTWs
depends:
    base-4.10.1.0 containers-0.5.10.2 bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-rfc5051/html/rfc5051.haddock
haddock-html: /usr/share/doc/haskell-rfc5051/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
